#
# spec file for package python-unyt
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-unyt
Version:        3.0.3
Release:        3.2
Summary:        A package for handling numpy arrays with units
License:        BSD-3-Clause
URL:            https://github.com/yt-project/unyt
Source:         https://files.pythonhosted.org/packages/source/u/unyt/unyt-%{version}.tar.gz
# PATCH-FIX-UPSTREAM unyt-pr512-np2.1.patch gh#yt-project/unyt#512
Patch0:         https://github.com/yt-project/unyt/pull/512.patch#/unyt-pr512-np2.1.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test
BuildRequires:  %{python_module dask-array}
BuildRequires:  %{python_module dask-diagnostics}
BuildRequires:  %{python_module numpy >= 1.19.3 with %python-numpy < 3}
BuildRequires:  %{python_module packaging >= 20.9}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module sympy >= 1.7}
# /SECTION
Requires:       (python-numpy >= 1.19.3 with python-numpy < 3)
Requires:       python-packaging > 20.9
Requires:       python-sympy >= 1.7
BuildArch:      noarch
%python_subpackages

%description
A package for handling numpy arrays with units.

Often writing code that deals with data that has units can be confusing. A
function might return an array but at least with plain NumPy arrays, there is no
way to easily tell what the units of the data are without somehow knowing *a
priori*.

%prep
%autosetup -p1 -n unyt-%{version}
sed -i 's/--color=yes//' pyproject.toml

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc *.rst
%license LICENSE
%{python_sitelib}/unyt
%{python_sitelib}/unyt-%{version}.dist-info

%changelog
* Fri Nov 15 2024 Ben Greiner <code@bnavigator.de>
- Add unyt-pr512-np2.1.patch for compatibility with numpy 2.1
  gh#yt-project/unyt#512
* Fri Jul 19 2024 Ben Greiner <code@bnavigator.de>
- Revert numpy restriction. It is explicitly supported upstream.
* Thu Jul 11 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.0.3:
  * BUG: fix signature incompatibilities in NEP 18 wrapped functions
  * BUG: fix an incompatibility with sympy 1.13.0rc1
- Restrict numpy to < 2.
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 3.0.2:
  * BUG: explicitly forbid destructive edits to the default unit
    registry
  * BLD: fix minimal requirement on setuptools_scm
  * TST: cleanup an unused skip condition
  * TST: fix usage of legacy numpy.random API in tests
  * BUG: fix an issue where array functions would raise
    UnitInconsistencyError when operands' units differ by some
    dimensionless factor
  * (NEP 18) Implement and test array functions new in numpy 2.0
  * BUG: fix compat with numpy dev for np.trapezoid (previously
    named np.trapz)
  * BUG: implement missing support for `np.cbrt`
  * BUG: fix compatibility with numpy 2.0 copy semantics
  * REL: prepare release 3.0.2
* Wed Feb 14 2024 Ben Greiner <code@bnavigator.de>
- Update to 3.0.1
  * BUG: fix backward compatibility for calling np.histogram with
    implicit range units by @neutrinoceros in #466
  * BUG: fix an issue where array functions would raise
    UnitConsistencyError on unyt arrays using non-default unit
    registries by @neutrinoceros in #463
  * TST: minimize build time in tox runs by @neutrinoceros in #426
  * BUG: fix an issue where array functions would crash
    (AttributeError) when passed non-ndarray array like objects
    (e.g. Python lists) by @neutrinoceros in #464
- Release 3.0.0
  * This new major release of unyt fixes a number of issues and
    adds a number of new features. Major contributions include:
  * Support for Python 3.8 has been dropped.
  * Support for Python 3.12 has been added.
  * Support for NumPy <1.19.3 has been dropped.
  * Support for SymPy <1.7 has been dropped.
  * NEP 18 support
  * A new unyt_dask_array class, which implements a subclass of
    standard dask arrays with units attached, has been added (PR
    [#185]). See :ref:`dask` for more details. Thank you to Chris
    Havlin (@chrishavlin on Github) for the contribution.
  * A number of new metric and non-metric units have been added in
    PR #441. Thank you to John ZuHone (@jzuhone on GitHub) for the
    contribution.
  * A number of common values for the solar metallicity found in
    the literature have been added as new metallicity units (PR
    [#315]). See :ref:`metal_conversions` for more details. Thank you
    to John ZuHone (@jzuhone on GitHub) for the contribution.
  * The "liter" unit has been added (PR #305). Thank you to Nathan
    Goldbaum (@ngoldbaum on GitHub) for the contribution.
  * The following common systems engineering units for energy have
    been added: MMBTU, therm, quad, and Wh (PR #294). Thank you to
    Sam Dotson (@samgdotson on GitHub) for the contribution.
  * The @returns decorator (documented in :ref:`checking_units`)
    now allows dimension-checking of multiple return values (PR
    [#435]). Thank you to Daniel Bates (@db434 on GitHub) for the
    contribution.
  * A fix for for the LaTeX representation of Planck units (PR
    [#379]). Thank you to Peter Hayman (@haymanpf on GitHub) for the
    contribution.
  * A fix for a bug that prevented the conversion of dimensionless
    arrays to their corresponding AstroPy Quantities (PR #437).
    Thank you to Clément Robert (@neutrinoceros on GitHub) for the
    contribution.
  * A fix for a bug in subtraction of temperature quantities that
    resulted in degC units being returned instead of delta_degC
    units (PR #413). Thank you to Clément Robert (@neutrinoceros on
    GitHub) for the contribution.
  * Fixes for issues with the comparison of temperature quantities
    (PR #408 and PR #412). Thank you to Clément Robert
    (@neutrinoceros on GitHub) for the contribution.
  * Support for versions of NumPy < 1.19 has been dropped in this
    version (PR #403). Thank you to Clément Robert (@neutrinoceros
    on GitHub) for the contribution.
  * Support NumPy 2.0
* Wed May 31 2023 Dirk Müller <dmueller@suse.com>
- update to 2.9.5:
  * Fix a regression where arrays elements with dtype ``'int8'``
    would not compare to floats as intended.
  * Raise an error in case an array element is assigned to a new
    value with incompatible units.
* Wed Feb  8 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to 2.9.4:
  * Make unyt_quantity.from_string parse ints. See PR #278. Thank you to Nahan
    Goldbaum (@ngoldbaum on GitHub) for the contribution.
  * TST: migrate from tox-pyenv to tox-gh-actions #344 See PR #344. Thank you
    to Clément Robert (@neutrinoceros on GitHub) for the contribution.
  * Correctly test string comparison depending on numpy version #358 See PR
    [#358]. Thank you to Clément Robert (@neutrinoceros on GitHub) for the
    contribution.
  * Multiple fixes for unyt_quantity.from_string
  - fix a bug where unyt_quantity.from_string would drop part of the unit
    expression
  - fix a bug where unyt_quantity.from_string would choke on unit expressions
    starting with '*' or '/'
  - fix a bug where unyt_quantity.from_string would choke on space-separated
    unit expressions
  - fix roundtrip for unyt_quantity.from_string and unyt_quantity.to_string
    methods
  - simplify unit regexp ('**/2' isn't a valid exponent)
  - fix a bug where malformed string input would be incorrectly parsed by
    unyt_quantity.from_string
- 2.9.3:
  * Fix a future incompatibility with numpy 1.25 (unreleased) where comparing
    unyt_array objects to non-numeric objects (e.g. strings) would cause a
    crash. See PR #333. Thank you to Clément Robert (@neutrinoceros on GitHub)
    and Nathan Goldbaum (@ngoldbaum on GitHub) for the contribution.
- 2.9.2:
  * Fix an issue where taking powers of units was backwards-incompatible with
    previous versions of unyt when the exponent is not zero. See PR #249. Thank
    you to Clément Robert (@neutrinoceros on GitHub) for the contribution.
  * The import time for unyt has been reduced by skipping version checking of
    other packages. See PR #251. Thank you to Clément Robert (@neutrinoceros on
    GitHub) for the contribution.
- 2.9.0:
  * Dropped support for Python 3.6 and 3.7.
  * Added support for Python 3.8, 3.9 and 3.10.
  * Fix an issue where SI prefixes of the degC units would give incorrect
    values in conversions. See PR #176. Thank you to Lee Johnston (@l-johnston
    on GitHub) for the contribution.
  * Fix an issue when using matplotlib_support, plot an empty unyt array, would
    result in an error when changing units. See PR #180. Thank you to Josh
    Borrow (@JBorrow on GitHub) for the contribution.
  * Fix an issue where units would be printed twice in formatted strings with
    an unyt_array embedded. See PR #188. Thank you to Clément Robert
    (@neutrinoceros on GitHub) for the contribution.
  * Add a method to parse a unyt_quantity from a string expression. See PR
    [#191]. Thank you to Clément Robert (@neutrinoceros on GitHub) for the
    contribution.
  * Fix an issue where a unyt_array with dtype int8 could not be converted to a
    different unit. See PR #197. Thank you to Clément Robert (@neutrinoceros on
    GitHub) for the contribution.
  * The import time for unyt has been reduced. See PR #199. Thank you to
    Clément Robert (@neutrinoceros on GitHub) for the contribution.
  * Fix an issue where taking an unyt_array or unyt_quantity to a zero power
    would retain the units of the original array or quantity instead of
    converting to a dimensionless array. See PR #204. Thank you to Josh Borrow
    (@JBorrow on GitHub) for the contribution.
  * Add support for coercing iterables of unyt_array objects with nonuniform
    dimensionally equivalent units to a single unyt_array. See PR #211. Thank
    you to Nathan Goldbaum (@ngoldbaum on GitHub) for the contribution.
  * Add the civil engineering units pli, plf, psf, kli, klf, and ksf. See PR
    [#217]. Thank you to @osnippet on GitHub for the contribution.
  * Fix typos in constants and unit prefixes. See PR #218. Thank you to Clément
    Robert (@neutrinoceros on GitHub) for the contribution.
  * Fix an issue where multiplying a 1-element unyt_array would return a
    unyt_quantity. See PR #225. Thank you to Clément Robert (@neutrinoceros on
    GitHub) for the contribution.
  * Add the Rydberg constant R_∞ and unit Ry, add the dimension
    angular_frequency and the unit rpm, and increase the precision of
    Avogadro's number. See PR #228.
  * Fix an issue where np.divide.reduce would return incorrect units for
    unyt_array instances. See PR #230. Thank you to Kyle Oman (@kyleaoman on
    GitHub) for the contribution.
* Tue Apr 27 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.8.0:
  * Dropped support for Python 3.5.
  * Add delta_degC and delta_degF units to support temperature difference arithmetic. See PR #152. Thank you to Lee Johnston (@l-johnston on GitHub) for the contribution.
  * Fix an issue where a subsequent load of the unit registry with units that are equal but not identical leads to a crash. See PR #158. Thank you to Matthew Turk (@matthewturk on GitHub) for the initial bug report and fix.
  * Add force unit kip and pressure unit psi. Thank you to P. Talley (@otaithleigh on GitHub) for the contribution. See PR #162.
  * Fix an issue where arithmetic operations on units defined in different registries and having the conversion defined in one direction would lead to a crash. See PR #164. Thank you to Clément Robert (@neutrinoceros on GitHub) for the initial bug report and fix.
- Do not build for Python 2, since no longer supported by upstream, and also
  do not build for Python 3.6, due to no NumPy.
* Mon Aug 31 2020 Tomáš Chvátal <tchvatal@suse.com>
- Initial commit, needed by python-yt
